@@ -1,21 +1,21 @@
 /*     -*-C++-*- -*-coding: utf-8-unix;-*-
-   Classified Ads is Copyright (c) Antti Järvinen 2013.
+  Classified Ads is Copyright (c) Antti Järvinen 2013-2018.
 
-   This file is part of Classified Ads.
+  This file is part of Classified Ads.
 
-    Classified Ads is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
+  Classified Ads is free software; you can redistribute it and/or
+  modify it under the terms of the GNU Lesser General Public
+  License as published by the Free Software Foundation; either
+  version 2.1 of the License, or (at your option) any later version.
 
-    Classified Ads is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
+  Classified Ads is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+  Lesser General Public License for more details.
 
-    You should have received a copy of the GNU Lesser General Public
-    License along with Classified Ads; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+  You should have received a copy of the GNU Lesser General Public
+  License along with Classified Ads; if not, write to the Free Software
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */
 #ifdef WIN32
 #define NOMINMAX
@@ -62,6 +62,11 @@ void NetworkConnectorEngine::run() {
     LOG_STR("NetworkConnectorEngine::run in") ;
     time_t timeOfLastNodeListUpdate (0) ;
     int connectedCount = 0 ; // initially must be, later ask datamodel
+
+    // subscribe to cleanup activities
+    connect(this, SIGNAL(finished()),
+	    this, SLOT(aboutToFinish())) ; 
+
     if (   iBroadCastSocket == NULL ) {
         iBroadCastSocket = new QUdpSocket() ;
     }
@@ -100,7 +105,7 @@ void NetworkConnectorEngine::run() {
     }
     delete iBroadCastSocket ;
     iBroadCastSocket = NULL ;
-    LOG_STR("NetworkConnectorEngine::run out") ;
+    LOG_STR("NetworkConnectorEngine::run out thread = " + QString::number((qulonglong)(QThread::currentThreadId()))) ;
 }
 
 bool NetworkConnectorEngine::tryServeWishListItem() {
@@ -607,3 +612,11 @@ bool NetworkConnectorEngine::performDNSLookup(QHostAddress* aAddressToBeSet,
     return isAddressSet ;
 }
 
+// slot that contains cleanup related to thread termination
+void NetworkConnectorEngine::aboutToFinish() {
+  QLOG_STR("NetworkConnectorEngine cleanup for thread " + QString::number((long)(QThread::currentThreadId()))  ) ; 
+  iModel->lock() ; 
+  iModel->threadTerminationCleanup(this) ; 
+  iModel->unlock() ; 
+  QLOG_STR("NetworkConnectorEngine cleanup out for thread " + QString::number((long)(QThread::currentThreadId()))  ) ; 
+}
